dot-assignParent: This returns or assigns the environment used in the :=...

.assignParentR Documentation

This returns or assigns the environment used in the ⁠:=⁠ operator

Description

This returns or assigns the environment used in the ⁠:=⁠ operator

Usage

.assignParent(env = NULL)

Arguments

env

environment to assign to; if NULL (the default), the current parent environment is returned.

Value

the environment used in the ⁠:=⁠ operator

Author(s)

Matthew L. Fidler

Examples

.assignParent()

nlmixr2save documentation built on Sept. 26, 2026, 1:07 a.m.