This returns or assigns the environment used in the := operator
Source: R/save.R
dot-assignParent.RdThis returns or assigns the environment used in the := operator

:= operatorR/save.R
dot-assignParent.RdThis returns or assigns the environment used in the := operator